#include "api/OceanMathCoreAPI.h"
#include <stdio.h>
#define PIXELCOUNT 1024
int main(int argc, char* argv[]) {
    // Do the calculation for a Blackbody spectrum at 6500 Kelvin
    const double colorTemperature = 6500.0;
    double wavelengths[PIXELCOUNT];
    double blackBody[PIXELCOUNT];

    // set up wavelengths at 0.5nm intevals starting at 300nm
    for (int pixel = 0; pixel < PIXELCOUNT; ++pixel) {
        wavelengths[pixel] = 300.0 + pixel * 0.5;
    }
    int error = 0;
    // Get the unnormalized Blackbody spectrum for the specified wavelengths
    int actualPixels = omapi_calculate_blackbody_spectrum_unnormalized(colorTemperature, wavelengths, PIXELCOUNT, blackBody, &error);
    // Check the error flag after the calculation
    if (error != 0) {
        printf("Error result %d in the Blackbody calculation\n", error);
    }
    else {
        // Find the spectrum peak value and index
        int peakPixelIndex = -1;
        double peakSpectrum = 0.0;
        for (int pixel = 0; pixel < PIXELCOUNT; ++pixel) {
            if (blackBody[pixel] > peakSpectrum) {
                peakSpectrum = blackBody[pixel];
                peakPixelIndex = pixel;
            }
        }
        // Convert the peak wavelength from nm to microns
        const double peakWavelengthMicrons = wavelengths[peakPixelIndex] / 1000.0;

        printf("Peak value is %f Watts per square metre per micron per steradian at wavelength %f microns",
            peakSpectrum, peakWavelengthMicrons);
    }
}