#include "api/OceanMathCoreAPI.h"
#include <iostream>
#include <algorithm>
int main() {
    // Do the calculation for a Blackbody spectrum at 6500 Kelvin
    const double colorTemperature = 6500.0;
    const unsigned int pixelCount = 1024;
    double wavelengths[pixelCount];
    double blackBody[pixelCount];

    // set up wavelengths at 0.5nm intevals starting at 300nm
    for (int pixel = 0; pixel < pixelCount; ++pixel) {
        wavelengths[pixel] = 300.0 + pixel * 0.5;
    }
    int error = 0;
    // Get the unnormalized Blackbody spectrum for the specified wavelengths
    int actualPixels = omapi_calculate_blackbody_spectrum_unnormalized(colorTemperature, wavelengths, pixelCount, blackBody, &error);
    // Check the error flag after the calculation
    if (error != 0) {
        std::cout << "Error result " << error << " in the Blackbody calculation" << std::endl;
    }
    else {
        // Find the spectrum peak value and index
        const double* peakSpectrum = std::max_element(blackBody, blackBody + pixelCount);
        auto peakPixelIndex = peakSpectrum - blackBody;
        // Convert the peak wavelength from nm to microns
        const double peakWavelengthMicrons = wavelengths[peakPixelIndex] / 1000.0;

        std::cout << "Peak value is " << *peakSpectrum << " Watts per square metre per micron per steradian at wavelength " << peakWavelengthMicrons << " microns" << std::endl;
    }
}