﻿using oceanmathnet.api;
using System;
using System.Linq;

namespace CoreCSharp
{
    class blackbodysample {
        static void Main(string[] args) {
            // Do the calculation for a Blackbody spectrum at 6500 Kelvin
            double colorTemperature = 6500.0;
            int pixelCount = 1024;
            double[] wavelengths = new double[pixelCount];

            // set up wavelengths at 0.5nm intevals starting at 300nm
            for (int pixel = 0; pixel < pixelCount; pixel++) {
                wavelengths[pixel] = 300.0 + pixel * 0.5;
            }
            int error = 0;
            // Get the unnormalized Blackbody spectrum for the specified wavelengths
            double[] blackBody = NetOceanMathCore.blackbodySpectrumUnnormalized(colorTemperature, wavelengths, ref error);
            // Check the error flag after the calculation
            if (error != 0) {
                Console.WriteLine(string.Format("Error result {0} in the Blackbody calculation", error));
            }
            else {
                // Find the spectrum peak value and index
                double peakSpectrum = blackBody.Max();
                int peakPixelIndex = blackBody.ToList().IndexOf(peakSpectrum);
                // Convert the peak wavelength from nm to microns
                double peakWavelengthMicrons = wavelengths[peakPixelIndex] / 1000.0;

                Console.WriteLine(string.Format("Peak value is {0} Watts per square metre per micron per steradian at wavelength {1} microns",
                    peakSpectrum, peakWavelengthMicrons));
            }
        }
    }
}
